Documentation
¶
Index ¶
- Variables
- func Create(entry types.LocationUpdate) (err error)
- func CreateMultiple(entries ...types.LocationUpdate) error
- func Delete() error
- func Destroy(filename string) error
- func Open(filename string) (*storm.DB, error)
- func Read(count int) (entries []types.DatabaseEntry, err error)
- func Update() error
- func Use(database *storm.DB) error
Constants ¶
This section is empty.
Variables ¶
var ( // Debug tells wheter or not printing debug messages Debug bool = false )
Functions ¶
func Create ¶
func Create(entry types.LocationUpdate) (err error)
Create saves a given entry to the database
func CreateMultiple ¶
func CreateMultiple(entries ...types.LocationUpdate) error
CreateMultiple saves multiple entries to the database.
func Open ¶
Open opens an existing database or creates one when it does not already exist. (i.e. a new .db file will be created), eventually, it points global variable `db` to it.
func Read ¶
func Read(count int) (entries []types.DatabaseEntry, err error)
Read retrieves entries from the database and returns them
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.